==> haskell-pandoc-crossref-0.2.5.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.5.0
id: pandoc-crossref-0.2.5.0-5RHbJUUdGQX9lDC1mu10qu
key: pandoc-crossref-0.2.5.0-5RHbJUUdGQX9lDC1mu10qu
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 9dad3956532cb12b32d8ac695efd9bee
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.5.0-5RHbJUUdGQX9lDC1mu10qu
depends:
    base-4.9.0.0 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-1.19.2.1-LZUBZWyrH6booXAhiWlmX
    pandoc-types-1.17.0.5-BVTbm6CGl39ABvvj1mHjGS
    roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    utility-ht-0.0.12-IQc75ZjtSJC6jKWDjW00eb
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-crossref-0.2.5.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.5.0
id: pandoc-crossref-0.2.5.0-5KzMiwbsDS7GoQRqHXQv4D
key: pandoc-crossref-0.2.5.0-5KzMiwbsDS7GoQRqHXQv4D
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: a1feacab89912ce0b649be2bfd4c345f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.5.0-5KzMiwbsDS7GoQRqHXQv4D
depends:
    base-4.9.0.0 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-9rU3hJ3Wexf6m7EcZLYdbr
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-1.19.2.1-FF4wBHUZbUs6T4UUg8i1NF
    pandoc-types-1.17.0.5-2bJKHPw7ZX5f0JaH4ZtGe
    roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    utility-ht-0.0.13-6LFtwAy4r2q397pbhjrZza
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
